@@ -35,7 +35,7 @@
 #'   read_sf() %>%
 #'   get_resources(get_teow()) %>%
 #'   calc_indicators(calc_ecoregion()) %>%
-#'   tidyr::unnest(ecoregion)
+#'   portfolio_long()
 #'
 #' aoi
 #' }
@@ -44,37 +44,20 @@ calc_ecoregion <- function() {
            teow = NULL,
            name = "ecoregion",
            mode = "asset",
+           aggregation = "sum",
            verbose = mapme_options()[["verbose"]]) {
     ECO_NAME <- NULL
-    new_area <- NULL
-    ecoregions <- NULL
-    area <- NULL
 
     if (nrow(teow[[1]]) == 0) {
-      return(NA)
+      return(NULL)
     }
 
-    merged <- .comp_teow(
+    .comp_teow(
       x = x,
       teow = teow,
+      var = ECO_NAME,
       verbose = verbose
     )
-
-    if (nrow(merged) == 0) {
-      return(NA)
-    }
-
-    out <- merged %>%
-      dplyr::select(ECO_NAME, new_area)
-
-    out_tibble <- tibble(
-      ecoregions = out[[1]],
-      area = out[[2]]
-    )
-
-    out_tibble %>%
-      dplyr::group_by(ecoregions) %>%
-      dplyr::summarise(area = sum(as.numeric(area)))
   }
 }
 
@@ -88,39 +71,55 @@ calc_ecoregion <- function() {
 
 .comp_teow <- function(x,
                        teow,
+                       var,
                        verbose = TRUE,
                        ...) {
   teow <- teow[[1]]
   teow <- st_make_valid(teow)
+  teow[["ECO_NAME"]] <- gsub("[-/&'() ]+", "_", tolower(teow[["ECO_NAME"]]))
+
   intersected <- suppressWarnings(st_intersection(x, teow))
   biome_and_name <- data.frame(
     BIOME = c(1:14, 98, 99),
     BIOME_NAME = c(
-      "Tropical & Subtropical Moist Broadleaf Forests",
-      "Tropical & Subtropical Dry Broadleaf Forests",
-      "Tropical & Subtropical Coniferous Forests",
-      "Temperate Broadleaf & Mixed Forests",
-      "Temperate Conifer Forests",
-      "Boreal Forests/Taiga",
-      "Tropical & Subtropical Grasslands, Savannas & Shrublands",
-      "Temperate Grasslands, Savannas & Shrublands",
-      "Flooded Grasslands & Savannas",
-      "Montane Grasslands & Shrublands",
-      "Tundra",
-      "Mediterranean Forests, Woodlands & Scrub",
-      "Deserts & Xeric Shrublands",
-      "Mangroves",
-      "Lake",
-      "Rock and Ice"
+      "tropical_subtropical_moist_broadleaf_forests",
+      "tropical_subtropical_dry_broadleaf_forests",
+      "tropical_subtropical_coniferous_forests",
+      "temperate_broadleaf_mixed_forests",
+      "temperate_conifer_forests",
+      "boreal_forests_taiga",
+      "tropical_subtropical_grasslands_savannas_shrublands",
+      "temperate_grasslands_savannas_shrublands",
+      "flooded_grasslands_savannas",
+      "montane_grasslands_shrublands",
+      "tundra",
+      "mediterranea_forests_woodlands_scrub",
+      "deserts_xeric_shrublands",
+      "mangroves",
+      "lake",
+      "rock_and_ice"
     )
   )
-  merged <- merge(intersected, biome_and_name)
-  area <- st_area(merged) %>%
-    as.numeric() %>%
-    `/`(., 10000)
-  merged <- st_drop_geometry(merged)
-  merged$new_area <- area
-  return(merged)
+
+  intersected <- merge(intersected, biome_and_name)
+  intersected$value <- as.numeric((st_area(intersected))) / 10000
+
+  if (nrow(intersected) == 0) {
+    return(NULL)
+  }
+
+  intersected %>%
+    sf::st_drop_geometry() %>%
+    dplyr::select({{ var }}, value) %>%
+    dplyr::mutate(
+      datetime = as.Date("2001-01-01"),
+      variable = {{ var }},
+      unit = "ha"
+    ) %>%
+    dplyr::select(datetime, variable, unit, value) %>%
+    dplyr::group_by(datetime, variable, unit) %>%
+    dplyr::summarise(value = sum(as.numeric(value))) %>%
+    dplyr::ungroup()
 }
 
 register_indicator(
