@@ -40,7 +40,7 @@
 #'   calc_indicators(
 #'     calc_elevation(engine = "extract", stats = c("mean", "median", "sd", "var"))
 #'   ) %>%
-#'   tidyr::unnest(elevation)
+#'   portfolio_long()
 #'
 #' aoi
 #' }
@@ -53,12 +53,13 @@ calc_elevation <- function(engine = "extract",
            nasa_srtm,
            name = "elevation",
            mode = "asset",
+           aggregation = "stat",
            verbose = mapme_options()[["verbose"]]) {
     if (is.null(nasa_srtm)) {
-      return(NA)
+      return(NULL)
     }
 
-    select_engine(
+    result <- select_engine(
       x = x,
       raster = nasa_srtm,
       stats = stats,
@@ -66,6 +67,14 @@ calc_elevation <- function(engine = "extract",
       name = "elevation",
       mode = "asset"
     )
+
+    result %>%
+      tidyr::pivot_longer(cols = dplyr::everything(), names_to = "variable") %>%
+      dplyr::mutate(
+        datetime = as.Date("2000-02-01"),
+        unit = "m"
+      ) %>%
+      dplyr::select(datetime, variable, unit, value)
   }
 }
 
