@@ -45,7 +45,7 @@
 #'   calc_indicators(
 #'     calc_population_count(engine = "extract", stats = c("sum", "median"))
 #'   ) %>%
-#'   tidyr::unnest(population_count)
+#'   portfolio_long()
 #'
 #' aoi
 #' }
@@ -57,9 +57,10 @@ calc_population_count <- function(engine = "extract", stats = "sum") {
            worldpop = NULL,
            name = "population_count",
            mode = "asset",
+           aggregation = "stat",
            verbose = mapme_options()[["verbose"]]) {
     if (is.null(worldpop)) {
-      return(NA)
+      return(NULL)
     }
 
     # set max value of 65535 to NA
@@ -75,13 +76,16 @@ calc_population_count <- function(engine = "extract", stats = "sum") {
       raster = worldpop,
       stats = stats,
       engine = engine,
-      name = "population_count",
+      name = "population",
       mode = "asset"
     )
 
     years <- unlist(lapply(names(worldpop), function(x) strsplit(x, "_")[[1]][2]))
-    results$year <- years
-    results
+    results[["datetime"]] <- as.Date(paste0(years, "-01-01"))
+    results[["unit"]] <- "count"
+    results %>%
+      tidyr::pivot_longer(-c(datetime, unit), names_to = "variable", values_to = "value") %>%
+      dplyr::select(datetime, variable, unit, value)
   }
 }
 
