@@ -43,18 +43,18 @@
 #' ) %>%
 #'   read_sf() %>%
 #'   get_resources(
-#'     get_gfw_treecover(version = "GFC-2020-v1.8"),
-#'     get_gfw_lossyear(version = "GFC-2020-v1.8"),
+#'     get_gfw_treecover(version = "GFC-2023-v1.11"),
+#'     get_gfw_lossyear(version = "GFC-2023-v1.11"),
 #'     get_gfw_emissions()
 #'   ) %>%
 #'   calc_indicators(
 #'     calc_treecover_area_and_emissions(years = 2016:2017, min_size = 1, min_cover = 30)
 #'   ) %>%
-#'   tidyr::unnest(treecover_area_and_emissions)
+#'   portfolio_long()
 #'
 #' aoi
 #' }
-calc_treecover_area_and_emissions <- function(years = 2000:2020,
+calc_treecover_area_and_emissions <- function(years = 2000:2023,
                                               min_size = 10,
                                               min_cover = 35) {
   check_namespace("exactextractr")
@@ -68,25 +68,38 @@ calc_treecover_area_and_emissions <- function(years = 2000:2020,
            gfw_emissions,
            name = "treecover_area_and_emissions",
            mode = "asset",
+           aggregation = "sum",
            verbose = mapme_options()[["verbose"]]) {
     # handling of return value if resources are missing, e.g. no overlap
     if (any(is.null(gfw_treecover), is.null(gfw_lossyear), is.null(gfw_emissions))) {
-      return(NA)
+      return(NULL)
     }
     # mask gfw
     gfw_treecover <- terra::mask(gfw_treecover, x)
     # check if gfw_treecover only contains 0s, e.g. on the ocean
     if (.gfw_empty_raster(gfw_treecover, min_cover)) {
-      return(tibble::tibble(years = years, emissions = 0, treecover = 0))
+      return(NULL)
     }
     # prepare gfw rasters
     gfw <- .gfw_prep_rasters(x, gfw_treecover, gfw_lossyear, gfw_emissions, min_cover)
 
+    # retrieves maximum lossyear value from layer name
+    max_year <- as.numeric(
+      gsub(
+        ".*GFC-([0-9]+)-.*", "\\1",
+        names(gfw_lossyear)
+      )
+    )
+
+    if (max_year < min(years)) {
+      return(NULL)
+    }
+
     gfw_stats <- exactextractr::exact_extract(
       gfw, x, function(data, min_size) {
         # retain only forest pixels and set area to ha
         data <- .prep_gfw_data(data, min_size)
-        losses <- .sum_gfw(data, "coverage_area")
+        losses <- .sum_gfw(data, "coverage_area", max_year)
         names(losses)[2] <- "loss"
         emissions <- .sum_gfw(data, "emissions")
 
@@ -117,9 +130,13 @@ calc_treecover_area_and_emissions <- function(years = 2000:2020,
       min_size = min_size, coverage_area = TRUE, summarize_df = TRUE
     )
 
-    rm(gfw)
-    gc()
-    tibble::as_tibble(gfw_stats)
+    gfw_stats %>%
+      tidyr::pivot_longer(-years, names_to = "variable") %>%
+      dplyr::mutate(
+        datetime = as.Date(paste0(years, "-01-01")),
+        unit = ifelse(variable == "treecover", "ha", "Mg")
+      ) %>%
+      dplyr::select(datetime, variable, unit, value)
   }
 }
 
