@@ -1,5 +1,5 @@
 test_that("active fire count works", {
-  shp <- read_sf(
+  x <- read_sf(
     system.file("extdata", "sierra_de_neiba_478140_2.gpkg",
       package = "mapme.biodiversity"
     )
@@ -7,32 +7,20 @@ test_that("active fire count works", {
   source <- list.files(system.file("res", "nasa_firms",
     package = "mapme.biodiversity"
   ), pattern = ".gpkg$", full.names = TRUE)
+
   nasa_firms <- read_sf(source)
   afc <- calc_active_fire_counts()
-  result <- afc(shp, list(nasa_firms))
-  expect_equal(
-    names(result),
-    c("instrument", "year", "active_fire_counts")
-  )
-  expect_equal(
-    result$instrument,
-    "VIIRS"
-  )
-  expect_equal(
-    result$year,
-    "2021"
-  )
-  expect_equal(
-    result$active_fire_counts,
-    21
-  )
+  expect_true(is.null(afc(x, NULL)))
+  result <- afc(x, list(nasa_firms))
+  expect_silent(.check_single_asset(result))
+  expect_true(inherits(result$datetime, "Date"))
+  expect_equal(result$value, 21)
 
   # test that it works with both VIRRS and MODIS sensors
   nasa_firms2 <- list(nasa_firms, nasa_firms)
   nasa_firms2[[2]]$instrument <- "MODIS"
-  result2 <- afc(shp, nasa_firms2)
-  expect_equal(
-    result2$instrument,
-    c("MODIS", "VIIRS")
-  )
+  result2 <- afc(x, nasa_firms2)
+  expect_silent(.check_single_asset(result2))
+  expect_equal(nrow(result2), 2)
+  expect_equal(result2$variable, c("modis_fire_count", "viirs_fire_count"))
 })
