@@ -1,10 +1,10 @@
 test_that("mangrove extent works", {
-  aoi <- read_sf(
+  x <- read_sf(
     system.file("extdata", "shell_beach_protected_area_41057_B.gpkg",
       package = "mapme.biodiversity"
     )
   )
-  aoi <- st_make_valid(aoi)
+  x <- st_make_valid(x)
   source <- list.files(system.file("res", "gmw",
     package = "mapme.biodiversity"
   ), pattern = ".gpkg$", full.names = TRUE)
@@ -14,18 +14,9 @@ test_that("mangrove extent works", {
   })
   names(gmw) <- basename(source)
   ma <- calc_mangroves_area()
-  result <- ma(aoi, gmw)
-  expect_equal(
-    names(result),
-    c("mangrove_extent", "year")
-  )
-  expect_equal(
-    result$mangrove_extent,
-    c(1214.88, 1206.61),
-    tolerance = 1e-4
-  )
-  expect_equal(
-    result$year,
-    c("1996", "2016")
-  )
+  expect_true(is.null(ma(x, NULL)))
+  result <- ma(x, gmw)
+  expect_equal(unique(result$variable), "mangroves")
+  expect_equal(result$value, c(1214.88, 1206.61), tolerance = 1e-4)
+  expect_equal(format(result$datetime, "%Y"), c("1996", "2016"))
 })
