@@ -7,23 +7,18 @@ test_that(".get_chirps works", {
   )
   aoi <- suppressWarnings(st_cast(aoi, to = "POLYGON")[1, ])
 
-  temp_loc <- file.path(tempdir(), "mapme.biodiversity")
-  dir.create(temp_loc, showWarnings = FALSE)
-  resource_dir <- system.file("res", package = "mapme.biodiversity")
-  file.copy(resource_dir, temp_loc, recursive = TRUE)
-  outdir <- file.path(tempdir(), "mapme.biodiversity", "res")
-  tmpdir <- tempdir()
+  outdir <- file.path(tempdir(), "mapme-data")
+  .copy_resource_dir(outdir)
 
   mapme_options(
     outdir = outdir,
-    tmpdir = tmpdir,
     verbose = FALSE,
     testing = TRUE
   )
 
-  gc <- get_chirps()
+  gc <- get_chirps(years = 2010)
   urls <- gc(aoi)
   exts <- unique(substr(urls, nchar(urls[1]) - 5, nchar(urls[1])))
   expect_equal(exts, "tif.gz")
-  expect_gte(length(urls), 518)
+  expect_gte(length(urls), 12)
 })
