@@ -14,32 +14,18 @@ test_that(".get_gfw_emissions works", {
   outdir <- file.path(tempdir(), "mapme.biodiversity", "res")
   tmpdir <- tempdir()
 
-  portfolio <- init_portfolio(aoi,
-    years = 2000:2020,
+  mapme_options(
     outdir = outdir,
     tmpdir = tmpdir,
-    verbose = FALSE
+    verbose = FALSE,
+    testing = TRUE
   )
 
-  # Add testing attribute in order to skip downloads
-  attributes(portfolio)$testing <- TRUE
-
-  expect_equal(
-    .get_gfw_emissions(portfolio),
-    "gfw_forest_carbon_gross_emissions_Mg_CO2e_px_20N_080W.tif"
-  )
-
-  # adds test to check for multiple polygons in the same tile
+  ge <- get_gfw_emissions()
+  expect_equal(ge(aoi), "gfw_forest_carbon_gross_emissions_Mg_CO2e_px_20N_080W.tif")
   splitted_aoi <- st_as_sf(st_make_grid(aoi, n = 2))
-  portfolio <- init_portfolio(splitted_aoi,
-    years = 2000:2020,
-    outdir = outdir,
-    tmpdir = tmpdir,
-    verbose = TRUE
-  )
-  attributes(portfolio)$testing <- TRUE
   expect_equal(
-    .get_gfw_emissions(portfolio),
+    ge(splitted_aoi),
     "gfw_forest_carbon_gross_emissions_Mg_CO2e_px_20N_080W.tif"
   )
 })
