@@ -1,10 +1,12 @@
 test_that("mapme_options works", {
   opts <- mapme_options()
-  expect_equal(names(opts), c("outdir", "verbose", "aria_bin", "testing"))
+  expect_equal(names(opts), c("outdir", "chunk_size", "verbose", "aria_bin",
+                              "testing", "log_dir"))
 
   expect_error(mapme_options(outdir = 1))
   expect_error(mapme_options(verbose = 1))
   expect_error(mapme_options(testing = 1))
+  expect_error(mapme_options(chunk_size = "a"))
 })
 
 test_that("test register_resource works", {
